@@ -8,8 +8,8 @@
 ;; Package-Requires: ((emacs "25.1"))
 ;; Maintainer: James Cherti
 ;; Original Author: Andy Stewart
-;; Package-Version: 1.0.4
-;; Package-Revision: 1.0.4-0-g43385cddb1e0
+;; Package-Version: 20250923.1446
+;; Package-Revision: 376d69a914b7
 ;; URL: https://github.com/jamescherti/quick-sdcv.el
 ;; Keywords: docs, startdict, sdcv
 
@@ -54,6 +54,10 @@
 ;; ------------------------
 ;; (use-package quick-sdcv
 ;;   :ensure t
+;;   :straight (quick-sdcv
+;;              :type git
+;;              :host github
+;;              :repo "jamescherti/quick-sdcv.el")
 ;;   :custom
 ;;   (quick-sdcv-dictionary-prefix-symbol "►")
 ;;   (quick-sdcv-ellipsis " ▼ "))
@@ -160,12 +164,6 @@ To apply the change, you need to execute `quick-sdcv-minor-mode' in the buffer."
   :type '(choice string (const nil))
   :group 'quick-sdcv)
 
-(defcustom quick-sdcv-ignore-pager t
-  "Ignore the SDCV_PAGER environment variable when running sdcv.
-If set to non-nil, the value of SDCV_PAGER is disregarded and not applied."
-  :type 'boolean
-  :group 'quick-sdcv)
-
 ;;; Variables
 
 (defvar quick-sdcv-current-translate-object nil
@@ -277,13 +275,10 @@ When ENABLED is nil: Deconstructs any symbol regions marked by '-->'."
            quick-sdcv-program))
   (with-temp-buffer
     (save-excursion
-      (let* ((process-environment
-              (if quick-sdcv-ignore-pager
-                  (cl-remove-if
-                   (lambda (var)
-                     (or (string-match "^SDCV_PAGER=" var)))
-                   process-environment)
-                process-environment)))
+      (let* ((process-environment (cl-remove-if
+                                   (lambda (var)
+                                     (or (string-match "^SDCV_PAGER=" var)))
+                                   process-environment)))
         (when quick-sdcv-hist-size
           (setenv "SDCV_HISTSIZE" (number-to-string quick-sdcv-hist-size)))
         (let ((exit-code (apply #'call-process quick-sdcv-program nil t nil
